/**
 * Copyright 2008,2009 Ivan SZKIBA
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * under the License.
 */

package net.sourceforge.tink.maven;

import net.sourceforge.tink.model.Output;

import org.apache.maven.plugin.logging.Log;

public class MojoOutput implements Output
{
    private final Log log;

    public MojoOutput(Log log)
    {
        this.log = log;
    }

    @Override public boolean isDebugEnabled()
    {
        return log.isDebugEnabled();
    }

    @Override public boolean isErrorEnabled()
    {
        return log.isErrorEnabled();
    }

    @Override public boolean isInfoEnabled()
    {
        return log.isInfoEnabled();
    }

    @Override public boolean isVerboseEnabled()
    {
        return log.isDebugEnabled();
    }

    @Override public boolean isWarningEnabled()
    {
        return log.isWarnEnabled();
    }

    @Override public void debug(String message, Object... params)
    {
        log.debug(String.format(message, params));
    }

    @Override public void debug(Throwable cause, String message, Object... params)
    {
        log.debug(String.format(message, params), cause);
    }

    @Override public void error(String message, Object... params)
    {
        log.error(String.format(message, params));
    }

    @Override public void error(Throwable cause, String message, Object... params)
    {
        log.error(String.format(message, params), cause);
    }

    @Override public void info(String message, Object... params)
    {
        log.info(String.format(message, params));
    }

    @Override public void info(Throwable cause, String message, Object... params)
    {
        log.info(String.format(message, params), cause);
    }

    @Override public void verbose(String message, Object... params)
    {
        log.debug(String.format(message, params));
    }

    @Override public void verbose(Throwable cause, String message, Object... params)
    {
        log.debug(String.format(message, params), cause);
    }

    @Override public void warning(String message, Object... params)
    {
        log.warn(String.format(message, params));
    }

    @Override public void warning(Throwable cause, String message, Object... params)
    {
        log.warn(String.format(message, params), cause);
    }
}
