/**
 * Copyright 2008,2009 Ivan SZKIBA
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * under the License.
 */

package net.sourceforge.tink.maven;

import net.sourceforge.tink.model.Output;
import net.sourceforge.tink.model.TinkException;
import net.sourceforge.tink.model.helpers.ProcessorBuilder;

import org.apache.maven.plugin.MojoExecutionException;

import org.apache.tools.ant.types.FileSet;

import java.io.File;

/**
 * Goal which process html files.
 *
 * @goal process
 *
 * @phase verify
 */
public class ProcessMojo extends AbstractTinkMojo implements ProcessorBuilder.Config
{

    /**
     * Location of the data file.
     * @parameter
     * @required
     */
    private File data;

    /**
     * Location of the generated pages.
     * @parameter
     * @required
     */
    private File destdir;

    /**
     * List of exclude patterns.
     * @parameter
     */
    private String[] excludes;

    /**
     * Location of the excludes file.
     * @parameter
     */
    private File excludesfile;

    /**
     * List of include patterns.
     * @parameter
     */
    private String[] includes;

    /**
     * Location of the includes file.
     * @parameter
     */
    private File includesfile;
    private Output output;

    /**
     * Location of the source html file.
     * @parameter
     * @required
     */
    private File srcdir;

    /**
     * Location of the page template file.
     * @parameter expression="${basedir}/src/site/conf/page.ftl"
     * @required
     */
    private File template;

    @Override public File getData()
    {
        return data;
    }

    @Override public File getDestdir()
    {
        return destdir;
    }

    @Override public String getExcludes()
    {
        return join(excludes);
    }

    public void setExcludes(String[] value)
    {
        excludes = value;
    }

    @Override public File getExcludesfile()
    {
        return excludesfile;
    }

    @Override public String getIncludes()
    {
        return join(includes);
    }

    public void setIncludes(String[] value)
    {
        includes = value;
    }

    @Override public File getIncludesfile()
    {
        return includesfile;
    }

    @Override public Output getOutput()
    {
        return output;
    }

    @Override public FileSet getSrc()
    {
        return null;
    }

    @Override public File getSrcdir()
    {
        return srcdir;
    }

    @Override public File getTemplate()
    {
        return template;
    }

    @Override public void execute() throws MojoExecutionException
    {
        output = new MojoOutput(getLog());
        try
        {
            new ProcessorBuilder(this).buildProcessor().execute();
        }
        catch (TinkException e)
        {
            throw new MojoExecutionException(e.getMessage(), e);
        }
    }
}
