/**
 * Copyright 2008,2009 Ivan SZKIBA
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * under the License.
 */

package net.sourceforge.tink.maven;

import net.sourceforge.tink.model.Output;
import net.sourceforge.tink.model.TinkException;
import net.sourceforge.tink.model.helpers.PublisherBuilder;

import org.apache.maven.plugin.MojoExecutionException;

import java.io.File;

import java.net.URI;
import java.net.URISyntaxException;

/**
 * Goal which publish generated html files.
 *
 * @goal publish
 *
 * @phase verify
 */
public class PublishMojo extends AbstractTinkMojo implements PublisherBuilder.Config
{

    /**
     * Location of the html files.
     * @parameter
     * @required
     */
    private File local;
    private Output output;

    /**
     * Password for destination URL
     * @parameter
     * @required
     */
    private String password;

    /**
     * Destination URL (only FTP schema supported currently)
     * @parameter
     * @required
     */
    private URI remote;

    /**
     * User name for destination URL
     * @parameter
     * @required
     */
    private String user;

    @Override public File getLocal()
    {
        return local;
    }

    @Override public Output getOutput()
    {
        return output;
    }

    @Override public String getPassword()
    {
        return password;
    }

    @Override public URI getRemote()
    {
        return remote;
    }

    public void setRemote(String value) throws URISyntaxException
    {
        remote = new URI(value);
    }

    @Override public String getUser()
    {
        return user;
    }

    @Override public void execute() throws MojoExecutionException
    {
        output = new MojoOutput(getLog());
        try
        {
            new PublisherBuilder(this).buildPublisher().execute();
        }
        catch (TinkException e)
        {
            throw new MojoExecutionException(e.getMessage(), e);
        }
    }
}
